==> tdevelop-trinity-14.0.13.tar.xz: tdevelop-trinity-14.0.13/lib/widgets/propeditor/pcursoredit.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Alexander Dymo                                  *
 *   cloudtemple@mskat.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef PCURSOREDIT_H
#define PCURSOREDIT_H

#include "pcombobox.h"

namespace PropertyLib{

/**
@short %Property editor for TQCursor values.
*/
class PCursorEdit: public PComboBox
{
    Q_OBJECT
  
public:
    PCursorEdit(MultiProperty* property, const TQMap<TQString, TQVariant> &spValues,
        TQWidget* parent = 0, const char* name = 0);

    virtual void drawViewer(TQPainter* p, const TQColorGroup& cg, const TQRect& r, const TQVariant& value);   
};

}

#endif

==> tdevelop-trinity_14.1.0.orig.tar.xz: tdevelop-trinity-14.1.0/lib/widgets/propeditor/pcursoredit.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Alexander Dymo                                  *
 *   cloudtemple@mskat.net                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU Library General Public License as       *
 *   published by the Free Software Foundation; either version 2 of the    *
 *   License, or (at your option) any later version.                       *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU Library General Public     *
 *   License along with this program; if not, write to the                 *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
 ***************************************************************************/
#ifndef PCURSOREDIT_H
#define PCURSOREDIT_H

#include "pcombobox.h"

namespace PropertyLib{

/**
@short %Property editor for TQCursor values.
*/
class PCursorEdit: public PComboBox
{
    Q_OBJECT
  
public:
    PCursorEdit(MultiProperty* property, const TQStringVariantMap &spValues,
        TQWidget* parent = 0, const char* name = 0);

    virtual void drawViewer(TQPainter* p, const TQColorGroup& cg, const TQRect& r, const TQVariant& value);   
};

}

#endif
